Client abstraction for Ad Manager SOAP API.
Client abstraction for Ad Manager SOAP API.
(call-wrapper this)Return a fn of one thunk that runs it, or nil for no wrapping.
Callers use this to impose rate-limiting / retry policy without this component taking on a resilience dependency.
Return a fn of one thunk that runs it, or nil for no wrapping. Callers use this to impose rate-limiting / retry policy without this component taking on a resilience dependency.
(service this service-key)Return a service for current session by service-key using services
factory.
Return a service for current session by `service-key` using services factory.
(services-factory this)(session this)(new credential application-name network-code wrap)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |